/* Produces a graph of a function.
 *
 *   12 May 1995
 *   Andrew D. Lewis
 *   California Institute of Technology
 */

#include<stdio.h>
#include<string.h>
#define FALSE 0
#define TRUE 1

double parms[10];

main(argc,argv)
int argc;
char *argv[];
{
  double x,y,xmin,xmax,xstep;
  double function();
  int itest,jtest;
  char *dummy,*thefile,*whatfile,*input_fn,*output_fn,*log_fn,UsingStdIn;
  char *basename();
  FILE *output_fp,*input_fp,*log_fp;

/* Check to see if argument is present. */
 
  if (argc < 1) {
    printf("\nUsage: func filename(.dat)\n\n");
    return 0;
  }

  if (argc == 2) {
    UsingStdIn = FALSE;
  }
  else {
    UsingStdIn = TRUE;
  }
 
/* Get filenames setup. */

  if (!UsingStdIn) {
    thefile = (char *)malloc(strlen(argv[1]));
    strcpy(thefile,argv[1]);
    whatfile = basename(thefile,".dat");
    input_fn = (char *)malloc(strlen(argv[1])+5);
    output_fn = (char *)malloc(strlen(argv[1])+4);
    log_fn = (char *)malloc(strlen(argv[1])+5);
    strcpy(input_fn,whatfile);
    strcat(input_fn,".finp");
    strcpy(output_fn,whatfile);
    strcat(output_fn,".dat");
    strcpy(log_fn,whatfile);
    strcat(log_fn,".flog");
  }

/* Input information from a file or from the screen. */

  if (!UsingStdIn) {
    itest = fopenerr(input_fn,-1);

    if (itest == -1) {

      jtest = fopenerr("finp.finp",1);
    
      if (jtest == -1) {
	printf("You will be asked to enter the input data by hand.\n");
	input_fp = stdin;
      }
      else {
	input_fp = fopen("finp.finp","r");
	printf("\nReading input information from finp.finp.\n");
      }
    }
    else {
      input_fp = fopen(input_fn,"r");
      printf("\nReading input information from %s.\n",input_fn);
    }
  }
  else {
    printf("You will be asked to enter the input data by hand.\n");
    input_fp = stdin;
  }

/* Open log file. */

  if (!UsingStdIn) {
    log_fp = fopen(log_fn,"w");
    fprintf(log_fp,"\n%s\n",log_fn);
    fclose(log_fp);
    dummy = (char *)malloc(strlen(log_fn)+8);
    strcpy(dummy,"date >> ");
    strcat(dummy,log_fn);
    system(dummy);
    log_fp = fopen(log_fn,"a");
  }

/* Get function parameters. */
 
  parmenter(parms,input_fp,log_fp,UsingStdIn);

/* Read plot parameters. */

  printf("Enter the initial x value.\n");
  fscanf(input_fp,"%lf",&xmin);
  if (!UsingStdIn) {
    fprintf(log_fp,"\nThe initial x value is: %lf\n",xmin);
  }

  printf("Enter the final x value.\n");
  fscanf(input_fp,"%lf",&xmax);
  if (!UsingStdIn) {
    fprintf(log_fp,"The final x value is: %lf\n",xmax);
  }

  printf("Enter the step.\n");
  fscanf(input_fp,"%lf",&xstep);
  if (!UsingStdIn) {
    fprintf(log_fp,"The step is: %lf\n\n",xstep);
  }

/* Close files. */

  fclose(input_fp);
  if (!UsingStdIn) fclose(log_fp);

/* Write to output file. */

  if (!UsingStdIn) {
    output_fp = fopen(output_fn,"w");
  }
  else {
    output_fp = stdout;
  }

  if (!UsingStdIn) {
    printf("\nWriting output on %s\n",output_fn);
  }

  x = xmin;
  y = function(x);

  fprintf(output_fp,"%lf  %lf\n",x,y);

  while (x < xmax) {
    x += xstep;
    y = function(x);
    fprintf(output_fp,"%lf  %lf\n",x,y);
  }

  fclose(output_fp);

  if (!UsingStdIn) {
    printf("\nOutput written on %s.\n",output_fn);
    printf("\nParticulars written on %s.\n\n",log_fn);
  }

  return 0;

}
