.TH FUNC L

.SH NAME
func - produces a data file which is the graph of a function.

.SH SYNOPSIS
func
.I [foo(.dat)]

.SH DESCRIPTION
.I func
will produce a file which contains a column where each row has two numbers,
the first being the value of the independent variable, and the second the
value of a user specified function evaluated at that independent variable.
The two numbers are separated by a space.  The file produced will be
.I foo.dat
(default is standard output).
.P
When
.I func
is executed, if the output is directed to
.I foo.dat,
it first looks for a file
.I finp.finp
from which to read input parameters, then it looks for
.I foo.finp.
If neither of these files are present, the input parameters are read from
standard input.  If the output is sent to standard output, the input will
have to be entered by standard input.
.P
The input parameters are:
.HP
- Parameters for the function (see below).
.HP
- The initial value of the independent variable.
.HP
- The final value for the independent variable.
.HP
- The increment for the independent variable.
.P
.I func
will prompt the user for these parameters, so it should be clear in practice
how this is done.

.SH SPECIFYING THE FUNCTION
The function whose graph is to be generated must be specified when
.I func
is compiled.  At compilation the function
.I function.c
is compiled and linked as part of the
.I func
executable.  In
.I function.c
you specify the function you wish to plot.  An example of a function is:
.P
.RS
.nf

/* Here's the formula for the function. */

#include<math.h>

double parms[10];

double function(x)
double x;

{
  double y;
  y = sin(parms[0] * x);
  return(y);
}

.fi
.RE
.P
It is probably best to simply modify the version of
.I function.c
which comes with the source code for
.I func.
If your function will have parameters, the declaration of
.I parms
must appear.  If you will be using more than 10 parameters, then the
value must also be changed in
.I func.c.
For more on parameters, see below.

.SH SPECIFYING PARAMETERS
It is possible with
.I func
to specify parameters for the function without having to recompile the
program.  This is done by the function
.I parmenter.c
which is compiled and linked when
.I func
is compiled.  A typical example of
.I parmenter.c
is
.P
.RS
.nf

/* Here is where the parameters are entered. */

#include<stdio.h>
 
parmenter(parms,input_fp,log_fp,UsingStdIn)
 
double parms[10];
FILE *input_fp,*log_fp;
char UsingStdIn;
 
{
  printf("\\nEnter the frequency in rad/sec.\\n");
  fscanf(input_fp,"%lf",&parms[0]);
  if (!UsingStdIn) {
    fprintf(log_fp,"\\nThe frequency is %lf rad/sec.\\n",parms[0]);
  }
}

.fi
.RE
.P
You should modify the version of
.I parmenter.c
given with the source code for
.I func.
The same comments about the array
.I parms
hold here as were made for function specification above.

.SH FILES
.TP 2.2i
.I %%binpath-name%%/func
executable file.
.TP 2.2i
.I %%demopath-name%%/function.c
an example of
.Ifunction.c.
.TP 2.2i
.I %%demopath-name%%/parmenter.c
an example of
.I parmenter.c.
.TP 2.2i
.I %%doc-name%%
.I LaTeX
documentation file.

.SH DIAGNOSTICS
If the data is not written to standard output, a log file,
.I foo.flog,
is created which contains a record of the input parameters.

.SH AUTHOR
Andrew D. Lewis, Queen's University, Kingston, ON, Canada,
<andrew@mast.queensu.ca>.
